@@ -10,7 +10,7 @@
  * @package    PhpMyAdmin
  * @subpackage Example
  */
-
+declare(strict_types=1);
 
 /**
  * This function returns username and password.
@@ -24,12 +24,16 @@
 function get_login_credentials($user)
 {
     /* Optionally we can use passed username */
-    if (!empty($user)) {
-        return array($user, 'password');
+    if (! empty($user)) {
+        return [
+            $user,
+            'password',
+        ];
     }
 
     /* Here we would retrieve the credentials */
-    $credentials = array('root', '');
-
-    return $credentials;
+    return [
+        'root',
+        '',
+    ];
 }
