@@ -285,7 +285,11 @@ if (isset($_POST['output_format']) && $_POST['output_format'] == 'sendit' && ! $
     $response->disable();
     //Disable all active buffers (see: ob_get_status(true) at this point)
     do {
-        $hasBuffer = @ob_end_clean();
+        if (ob_get_length() > 0) {
+            $hasBuffer = ob_end_clean();
+        } else {
+            $hasBuffer = false;
+        }
     } while ($hasBuffer);
 }
 
