@@ -113,7 +113,7 @@ class Config
      */
     public function checkSystem(): void
     {
-        $this->set('PMA_VERSION', '5.0.1');
+        $this->set('PMA_VERSION', '5.0.2');
         /* Major version */
         $this->set(
             'PMA_MAJOR_VERSION',
@@ -1361,6 +1361,9 @@ class Config
         } elseif (strtolower(Core::getenv('HTTP_CLOUDFRONT_FORWARDED_PROTO')) === 'https') {
             // Amazon CloudFront, issue #15621
             $is_https = true;
+        } elseif (Util::getProtoFromForwardedHeader(Core::getenv('HTTP_FORWARDED')) === 'https') {
+            // RFC 7239 Forwarded header
+            $is_https = true;
         } elseif (Core::getenv('SERVER_PORT') == 443) {
             $is_https = true;
         }
