@@ -44,6 +44,13 @@ class SearchController extends AbstractController
      * @var array
      */
     private $_columnTypes;
+    /**
+     * Types of columns without any replacement
+     *
+     * @access private
+     * @var array
+     */
+    private $_originalColumnTypes;
     /**
      * Collations of columns
      *
@@ -116,6 +123,7 @@ class SearchController extends AbstractController
         $this->_columnNames = [];
         $this->_columnNullFlags = [];
         $this->_columnTypes = [];
+        $this->_originalColumnTypes = [];
         $this->_columnCollations = [];
         $this->_geomColumnFlag = false;
         $this->_foreigners = [];
@@ -150,6 +158,8 @@ class SearchController extends AbstractController
             $this->_columnNames[] = $row['Field'];
 
             $type = $row['Type'];
+            // before any replacement
+            $this->_originalColumnTypes[] = mb_strtolower($type);
             // check whether table contains geometric columns
             if (in_array($type, $geom_types)) {
                 $this->_geomColumnFlag = true;
@@ -443,8 +453,8 @@ class SearchController extends AbstractController
     public function getDataRowAction()
     {
         $extra_data = [];
-        $row_info_query = 'SELECT * FROM `' . $_POST['db'] . '`.`'
-            . $_POST['table'] . '` WHERE ' . $_POST['where_clause'];
+        $row_info_query = 'SELECT * FROM ' . Util::backquote($_POST['db']) . '.'
+            . Util::backquote($_POST['table']) . ' WHERE ' .  $_POST['where_clause'];
         $result = $this->dbi->query(
             $row_info_query . ";",
             DatabaseInterface::CONNECT_USER,
@@ -935,9 +945,10 @@ class SearchController extends AbstractController
         //Gets column's type and collation
         $type = $this->_columnTypes[$column_index];
         $collation = $this->_columnCollations[$column_index];
+        $cleanType = preg_replace('@\(.*@s', '', $type);
         //Gets column's comparison operators depending on column type
         $typeOperators = $this->dbi->types->getTypeOperatorsHtml(
-            preg_replace('@\(.*@s', '', $this->_columnTypes[$column_index]),
+            $cleanType,
             $this->_columnNullFlags[$column_index],
             $selected_operator
         );
@@ -953,9 +964,27 @@ class SearchController extends AbstractController
             '',
             ''
         );
+        $html_attributes = '';
+        if (in_array($cleanType, $this->dbi->types->getIntegerTypes())) {
+            $extracted_columnspec = Util::extractColumnSpec(
+                $this->_originalColumnTypes[$column_index]
+            );
+            $is_unsigned = $extracted_columnspec['unsigned'];
+            $min_max_values = $this->dbi->types->getIntegerRange(
+                $cleanType,
+                ! $is_unsigned
+            );
+            $html_attributes = 'min="' . $min_max_values[0] . '" '
+                            . 'max="' . $min_max_values[1] . '"';
+            $type = 'INT';
+        }
+
+        $html_attributes .= " onchange= 'return verifyAfterSearchFieldChange(" . $column_index . ")'";
+
         $value = $this->template->render('table/search/input_box', [
             'str' => '',
             'column_type' => (string) $type,
+            'html_attributes' => $html_attributes,
             'column_id' => 'fieldID_',
             'in_zoom_search_edit' => false,
             'foreigners' => $this->_foreigners,
