@@ -5,11 +5,11 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin;
 
-use PhpMyAdmin\Relation;
-use PhpMyAdmin\Template;
-use PhpMyAdmin\Url;
+use PhpMyAdmin\Error;
 use PhpMyAdmin\Utils\HttpRequest;
 
 /**
@@ -24,7 +24,7 @@ class ErrorReport
      *
      * @var string
      */
-    private $submissionUrl;
+    private $submissionUrl = 'https://reports.phpmyadmin.net/incidents/create';
 
     /**
      * @var HttpRequest
@@ -32,20 +32,38 @@ class ErrorReport
     private $httpRequest;
 
     /**
-     * @var Relation $relation
+     * @var Relation
      */
     private $relation;
 
+    /**
+     * @var Template
+     */
+    public $template;
+
     /**
      * Constructor
      *
      * @param HttpRequest $httpRequest HttpRequest instance
+     * @param Relation    $relation    Relation instance
+     * @param Template    $template    Template instance
      */
-    public function __construct(HttpRequest $httpRequest)
+    public function __construct(HttpRequest $httpRequest, Relation $relation, Template $template)
     {
         $this->httpRequest = $httpRequest;
-        $this->submissionUrl = 'https://reports.phpmyadmin.net/incidents/create';
-        $this->relation = new Relation();
+        $this->relation = $relation;
+        $this->template = $template;
+    }
+
+    /**
+     * Set the URL where to submit reports to
+     *
+     * @param string $submissionUrl Submission URL
+     * @return void
+     */
+    public function setSubmissionUrl(string $submissionUrl): void
+    {
+        $this->submissionUrl = $submissionUrl;
     }
 
     /**
@@ -55,7 +73,7 @@ class ErrorReport
      *
      * @return string the report
      */
-    private function getPrettyData()
+    private function getPrettyData(): string
     {
         $report = $this->getData();
 
@@ -70,8 +88,11 @@ class ErrorReport
      *
      * @return array error report if success, Empty Array otherwise
      */
-    public function getData($exceptionType = 'js')
+    public function getData(string $exceptionType = 'js'): array
     {
+        /** @var Config $PMA_Config */
+        global $PMA_Config;
+
         $relParams = $this->relation->getRelationsParam();
         // common params for both, php & js exceptions
         $report = [
@@ -81,10 +102,10 @@ class ErrorReport
             "user_os" => PMA_USR_OS,
             "server_software" => $_SERVER['SERVER_SOFTWARE'],
             "user_agent_string" => $_SERVER['HTTP_USER_AGENT'],
-            "locale" => $_COOKIE['pma_lang'],
+            "locale" => $PMA_Config->getCookie('pma_lang'),
             "configuration_storage" =>
-                is_null($relParams['db']) ? "disabled" : "enabled",
-            "php_version" => phpversion()
+                $relParams['db'] === null ? "disabled" : "enabled",
+            "php_version" => PHP_VERSION,
         ];
 
         if ($exceptionType == 'js') {
@@ -99,7 +120,7 @@ class ErrorReport
                 $exception["uri"] = $uri;
                 $report["script_name"] = $scriptName;
                 unset($exception["url"]);
-            } else if (isset($_POST["url"])) {
+            } elseif (isset($_POST["url"])) {
                 list($uri, $scriptName) = $this->sanitizeUrl($_POST["url"]);
                 $exception["uri"] = $uri;
                 $report["script_name"] = $scriptName;
@@ -121,13 +142,13 @@ class ErrorReport
             $errors = [];
             // create php error report
             $i = 0;
-            if (!isset($_SESSION['prev_errors'])
+            if (! isset($_SESSION['prev_errors'])
                 || $_SESSION['prev_errors'] == ''
             ) {
                 return [];
             }
             foreach ($_SESSION['prev_errors'] as $errorObj) {
-                /* @var $errorObj PhpMyAdmin\Error */
+                /** @var Error $errorObj */
                 if ($errorObj->getLine()
                     && $errorObj->getType()
                     && $errorObj->getNumber() != E_USER_WARNING
@@ -138,14 +159,14 @@ class ErrorReport
                         "type" => $errorObj->getType(),
                         "msg" => $errorObj->getOnlyMessage(),
                         "stackTrace" => $errorObj->getBacktrace(5),
-                        "stackhash" => $errorObj->getHash()
+                        "stackhash" => $errorObj->getHash(),
                     ];
                 }
             }
 
             // if there were no 'actual' errors to be submitted.
-            if ($i==0) {
-                return [];   // then return empty array
+            if ($i == 0) {
+                return []; // then return empty array
             }
             $report["exception_type"] = 'php';
             $report["errors"] = $errors;
@@ -168,7 +189,7 @@ class ErrorReport
      *
      * @return array the uri and script name
      */
-    private function sanitizeUrl($url)
+    private function sanitizeUrl(string $url): array
     {
         $components = parse_url($url);
         if (isset($components["fragment"])
@@ -200,7 +221,10 @@ class ErrorReport
         }
 
         $uri = $scriptName . "?" . $query;
-        return [$uri, $scriptName];
+        return [
+            $uri,
+            $scriptName,
+        ];
     }
 
     /**
@@ -212,14 +236,13 @@ class ErrorReport
      */
     public function send(array $report)
     {
-        $response = $this->httpRequest->create(
+        return $this->httpRequest->create(
             $this->submissionUrl,
             "POST",
             false,
             json_encode($report),
             "Content-Type: application/json"
         );
-        return $response;
     }
 
     /**
@@ -228,9 +251,9 @@ class ErrorReport
      *
      * @param array $stack the stack trace
      *
-     * @return array $stack the modified stack trace
+     * @return array the modified stack trace
      */
-    private function translateStacktrace(array $stack)
+    private function translateStacktrace(array $stack): array
     {
         foreach ($stack as &$level) {
             foreach ($level["context"] as &$line) {
@@ -253,7 +276,7 @@ class ErrorReport
      *
      * @return string the form
      */
-    public function getForm()
+    public function getForm(): string
     {
         $datas = [
             'report_data' => $this->getPrettyData(),
@@ -262,10 +285,10 @@ class ErrorReport
         ];
 
         $reportData = $this->getData();
-        if (!empty($reportData)) {
-            $datas['hidden_fields'] = Url::getHiddenFields($reportData);
+        if (! empty($reportData)) {
+            $datas['hidden_fields'] = Url::getHiddenFields($reportData, '', true);
         }
 
-        return Template::get('error/report_form')->render($datas);
+        return $this->template->render('error/report_form', $datas);
     }
 }
