@@ -5,17 +5,10 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin;
 
-use PhpMyAdmin\Config;
-use PhpMyAdmin\Core;
-use PhpMyAdmin\Message;
-use PhpMyAdmin\Relation;
-use PhpMyAdmin\Response;
-use PhpMyAdmin\Sanitize;
-use PhpMyAdmin\Scripts;
-use PhpMyAdmin\Url;
-use PhpMyAdmin\Util;
 use Traversable;
 
 /**
@@ -56,19 +49,25 @@ class Footer
     private $_isEnabled;
 
     /**
-     * @var Relation $relation
+     * @var Relation
      */
     private $relation;
 
+    /**
+     * @var Template
+     */
+    private $template;
+
     /**
      * Creates a new class instance
      */
     public function __construct()
     {
+        $this->template = new Template();
         $this->_isEnabled = true;
-        $this->_scripts   = new Scripts();
+        $this->_scripts = new Scripts();
         $this->_isMinimal = false;
-        $this->relation = new Relation();
+        $this->relation = new Relation($GLOBALS['dbi']);
     }
 
     /**
@@ -76,17 +75,17 @@ class Footer
      *
      * @return string
      */
-    private function _getDemoMessage()
+    private function _getDemoMessage(): string
     {
         $message = '<a href="/">' . __('phpMyAdmin Demo Server') . '</a>: ';
-        if (@file_exists('./revision-info.php')) {
-            include './revision-info.php';
+        if (@file_exists(ROOT_PATH . 'revision-info.php')) {
+            include ROOT_PATH . 'revision-info.php';
             $message .= sprintf(
                 __('Currently running Git revision %1$s from the %2$s branch.'),
-                '<a target="_blank" rel="noopener noreferrer" href="' . $repobase . $fullrevision . '">'
-                . $revision . '</a>',
-                '<a target="_blank" rel="noopener noreferrer" href="' . $repobranchbase . $branch . '">'
-                . $branch . '</a>'
+                '<a target="_blank" rel="noopener noreferrer" href="' . htmlspecialchars($repobase . $fullrevision) . '">'
+                . htmlspecialchars($revision) . '</a>',
+                '<a target="_blank" rel="noopener noreferrer" href="' . htmlspecialchars($repobranchbase . $branch) . '">'
+                . htmlspecialchars($branch) . '</a>'
             );
         } else {
             $message .= __('Git information missing!');
@@ -98,18 +97,18 @@ class Footer
     /**
      * Remove recursions and iterator objects from an object
      *
-     * @param object|array &$object Object to clean
-     * @param array        $stack   Stack used to keep track of recursion,
-     *                              need not be passed for the first time
+     * @param object|array $object Object to clean
+     * @param array        $stack  Stack used to keep track of recursion,
+     *                             need not be passed for the first time
      *
      * @return object Reference passed object
      */
-    private static function _removeRecursion(&$object, array $stack = array())
+    private static function _removeRecursion(&$object, array $stack = [])
     {
         if ((is_object($object) || is_array($object)) && $object) {
             if ($object instanceof Traversable) {
                 $object = "***ITERATOR***";
-            } elseif (!in_array($object, $stack, true)) {
+            } elseif (! in_array($object, $stack, true)) {
                 $stack[] = $object;
                 foreach ($object as &$subobject) {
                     self::_removeRecursion($subobject, $stack);
@@ -126,21 +125,21 @@ class Footer
      *
      * @return string
      */
-    public function getDebugMessage()
+    public function getDebugMessage(): string
     {
         $retval = '\'null\'';
         if ($GLOBALS['cfg']['DBG']['sql']
             && empty($_REQUEST['no_debug'])
-            && !empty($_SESSION['debug'])
+            && ! empty($_SESSION['debug'])
         ) {
             // Remove recursions and iterators from $_SESSION['debug']
             self::_removeRecursion($_SESSION['debug']);
 
-            $retval = JSON_encode($_SESSION['debug']);
-            $_SESSION['debug'] = array();
+            $retval = json_encode($_SESSION['debug']);
+            $_SESSION['debug'] = [];
             return json_last_error() ? '\'false\'' : $retval;
         }
-        $_SESSION['debug'] = array();
+        $_SESSION['debug'] = [];
         return $retval;
     }
 
@@ -149,20 +148,20 @@ class Footer
      *
      * @return string
      */
-    public function getSelfUrl()
+    public function getSelfUrl(): string
     {
         $db = isset($GLOBALS['db']) && strlen($GLOBALS['db']) ? $GLOBALS['db'] : '';
         $table = isset($GLOBALS['table']) && strlen($GLOBALS['table']) ? $GLOBALS['table'] : '';
         $target = isset($_REQUEST['target']) && strlen($_REQUEST['target']) ? $_REQUEST['target'] : '';
-        $params = array(
+        $params = [
             'db' => $db,
             'table' => $table,
             'server' => $GLOBALS['server'],
-            'target' => $target
-        );
+            'target' => $target,
+        ];
         // needed for server privileges tabs
         if (isset($_GET['viewing_mode'])
-            && in_array($_GET['viewing_mode'], array('server', 'db', 'table'))
+            && in_array($_GET['viewing_mode'], ['server', 'db', 'table'])
         ) {
             $params['viewing_mode'] = $_GET['viewing_mode'];
         }
@@ -185,7 +184,7 @@ class Footer
             $params['checkprivstable'] = $_GET['checkprivstable'];
         }
         if (isset($_REQUEST['single_table'])
-            && in_array($_REQUEST['single_table'], array(true, false))
+            && in_array($_REQUEST['single_table'], [true, false])
         ) {
             $params['single_table'] = $_REQUEST['single_table'];
         }
@@ -199,7 +198,7 @@ class Footer
      *
      * @return string
      */
-    private function _getSelfLink($url)
+    private function _getSelfLink(string $url): string
     {
         $retval  = '';
         $retval .= '<div id="selflink" class="print_ignore">';
@@ -223,7 +222,7 @@ class Footer
      *
      * @return string
      */
-    public function getErrorMessages()
+    public function getErrorMessages(): string
     {
         $retval = '';
         if ($GLOBALS['error_handler']->hasDisplayErrors()) {
@@ -243,7 +242,7 @@ class Footer
      *
      * @return void
      */
-    private function _setHistory()
+    private function _setHistory(): void
     {
         if (! Core::isValid($_REQUEST['no_history'])
             && empty($GLOBALS['error_message'])
@@ -265,7 +264,7 @@ class Footer
      *
      * @return void
      */
-    public function disable()
+    public function disable(): void
     {
         $this->_isEnabled = false;
     }
@@ -278,9 +277,9 @@ class Footer
      *
      * @return void
      */
-    public function setAjax($isAjax)
+    public function setAjax(bool $isAjax): void
     {
-        $this->_isAjax = (boolean) $isAjax;
+        $this->_isAjax = $isAjax;
     }
 
     /**
@@ -288,7 +287,7 @@ class Footer
      *
      * @return void
      */
-    public function setMinimal()
+    public function setMinimal(): void
     {
         $this->_isMinimal = true;
     }
@@ -298,7 +297,7 @@ class Footer
      *
      * @return Scripts object
      */
-    public function getScripts()
+    public function getScripts(): Scripts
     {
         return $this->_scripts;
     }
@@ -308,14 +307,10 @@ class Footer
      *
      * @return string
      */
-    public function getDisplay()
+    public function getDisplay(): string
     {
-        $retval = '';
         $this->_setHistory();
         if ($this->_isEnabled) {
-            if (! $this->_isAjax) {
-                $retval .= "</div>";
-            }
             if (! $this->_isAjax && ! $this->_isMinimal) {
                 if (Core::getenv('SCRIPT_NAME')
                     && empty($_POST)
@@ -329,7 +324,7 @@ class Footer
                     $this->_scripts->addCode(
                         sprintf(
                             'if (! (history && history.pushState)) '
-                            . 'PMA_MicroHistory.primer = {'
+                            . 'MicroHistory.primer = {'
                             . ' url: "%s",'
                             . ' scripts: %s,'
                             . ' menuHash: "%s"'
@@ -344,28 +339,32 @@ class Footer
                     && ! $this->_isAjax
                 ) {
                     $url = $this->getSelfUrl();
-                    $retval .= $this->_getSelfLink($url);
+                    $selfLink = $this->_getSelfLink($url);
                 }
                 $this->_scripts->addCode(
                     'var debugSQLInfo = ' . $this->getDebugMessage() . ';'
                 );
-                $retval .= '<div class="clearfloat" id="pma_errors">';
-                $retval .= $this->getErrorMessages();
-                $retval .= '</div>';
-                $retval .= $this->_scripts->getDisplay();
+
+                $errorMessages = $this->getErrorMessages();
+                $scripts = $this->_scripts->getDisplay();
+
                 if ($GLOBALS['cfg']['DBG']['demo']) {
-                    $retval .= '<div id="pma_demo">';
-                    $retval .= $this->_getDemoMessage();
-                    $retval .= '</div>';
+                    $demoMessage = $this->_getDemoMessage();
                 }
 
-                $retval .= Config::renderFooter();
-            }
-            if (! $this->_isAjax) {
-                $retval .= "</body></html>";
+                $footer = Config::renderFooter();
             }
+            return $this->template->render('footer', [
+                'is_ajax' => $this->_isAjax,
+                'is_minimal' => $this->_isMinimal,
+                'self_link' => $selfLink ?? '',
+                'error_messages' => $errorMessages ?? '',
+                'scripts' => $scripts ?? '',
+                'is_demo' => $GLOBALS['cfg']['DBG']['demo'],
+                'demo_message' => $demoMessage ?? '',
+                'footer' => $footer ?? '',
+            ]);
         }
-
-        return $retval;
+        return '';
     }
 }
