@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin;
 
 use PhpMyAdmin\Sanitize;
@@ -43,25 +45,25 @@ use PhpMyAdmin\Util;
  */
 class Message
 {
-    const SUCCESS = 1; // 0001
-    const NOTICE  = 2; // 0010
-    const ERROR   = 8; // 1000
+    public const SUCCESS = 1; // 0001
+    public const NOTICE  = 2; // 0010
+    public const ERROR   = 8; // 1000
 
-    const SANITIZE_NONE   = 0;  // 0000 0000
-    const SANITIZE_STRING = 16; // 0001 0000
-    const SANITIZE_PARAMS = 32; // 0010 0000
-    const SANITIZE_BOOTH  = 48; // 0011 0000
+    public const SANITIZE_NONE   = 0;  // 0000 0000
+    public const SANITIZE_STRING = 16; // 0001 0000
+    public const SANITIZE_PARAMS = 32; // 0010 0000
+    public const SANITIZE_BOOTH  = 48; // 0011 0000
 
     /**
      * message levels
      *
      * @var array
      */
-    static public $level = array (
+    public static $level =  [
         Message::SUCCESS => 'success',
         Message::NOTICE  => 'notice',
         Message::ERROR   => 'error',
-    );
+    ];
 
     /**
      * The message number
@@ -117,7 +119,7 @@ class Message
      * @access  protected
      * @var     array
      */
-    protected $params = array();
+    protected $params = [];
 
     /**
      * holds additional messages
@@ -125,7 +127,7 @@ class Message
      * @access  protected
      * @var     array
      */
-    protected $addedMessages = array();
+    protected $addedMessages = [];
 
     /**
      * Constructor
@@ -136,12 +138,15 @@ class Message
      * @param integer $sanitize A flag to indicate what to sanitize, see
      *                          constant definitions above
      */
-    public function __construct($string = '', $number = Message::NOTICE,
-        array $params = array(), $sanitize = Message::SANITIZE_NONE
+    public function __construct(
+        string $string = '',
+        int $number = Message::NOTICE,
+        array $params = [],
+        int $sanitize = Message::SANITIZE_NONE
     ) {
-        $this->setString($string, $sanitize & Message::SANITIZE_STRING);
+        $this->setString($string, $sanitize & self::SANITIZE_STRING);
         $this->setNumber($number);
-        $this->setParams($params, $sanitize & Message::SANITIZE_PARAMS);
+        $this->setParams($params, $sanitize & self::SANITIZE_PARAMS);
     }
 
     /**
@@ -149,7 +154,7 @@ class Message
      *
      * @return string
      */
-    public function __toString()
+    public function __toString(): string
     {
         return $this->getMessage();
     }
@@ -166,13 +171,13 @@ class Message
      * @return Message
      * @static
      */
-    static public function success($string = '')
+    public static function success(string $string = ''): self
     {
         if (empty($string)) {
             $string = __('Your SQL query has been executed successfully.');
         }
 
-        return new Message($string, Message::SUCCESS);
+        return new Message($string, self::SUCCESS);
     }
 
     /**
@@ -185,13 +190,13 @@ class Message
      * @return Message
      * @static
      */
-    static public function error($string = '')
+    public static function error(string $string = ''): self
     {
         if (empty($string)) {
             $string = __('Error');
         }
 
-        return new Message($string, Message::ERROR);
+        return new Message($string, self::ERROR);
     }
 
     /**
@@ -207,9 +212,9 @@ class Message
      * @return Message
      * @static
      */
-    static public function notice($string)
+    public static function notice(string $string): self
     {
-        return new Message($string, Message::NOTICE);
+        return new Message($string, self::NOTICE);
     }
 
     /**
@@ -223,7 +228,7 @@ class Message
      * @return Message
      * @static
      */
-    static public function raw($message, $type = Message::NOTICE)
+    public static function raw(string $message, int $type = Message::NOTICE): self
     {
         $r = new Message('', $type);
         $r->setMessage($message);
@@ -241,9 +246,9 @@ class Message
      * @return Message
      * @static
      */
-    static public function getMessageForAffectedRows($rows)
+    public static function getMessageForAffectedRows(int $rows): self
     {
-        $message = Message::success(
+        $message = self::success(
             _ngettext('%1$d row affected.', '%1$d rows affected.', $rows)
         );
         $message->addParam($rows);
@@ -260,9 +265,9 @@ class Message
      * @return Message
      * @static
      */
-    static public function getMessageForDeletedRows($rows)
+    public static function getMessageForDeletedRows(int $rows): self
     {
-        $message = Message::success(
+        $message = self::success(
             _ngettext('%1$d row deleted.', '%1$d rows deleted.', $rows)
         );
         $message->addParam($rows);
@@ -279,9 +284,9 @@ class Message
      * @return Message
      * @static
      */
-    static public function getMessageForInsertedRows($rows)
+    public static function getMessageForInsertedRows(int $rows): self
     {
-        $message = Message::success(
+        $message = self::success(
             _ngettext('%1$d row inserted.', '%1$d rows inserted.', $rows)
         );
         $message->addParam($rows);
@@ -298,9 +303,9 @@ class Message
      * @return Message
      * @static
      */
-    static public function rawError($message)
+    public static function rawError(string $message): self
     {
-        return Message::raw($message, Message::ERROR);
+        return self::raw($message, self::ERROR);
     }
 
     /**
@@ -313,9 +318,9 @@ class Message
      * @return Message
      * @static
      */
-    static public function rawNotice($message)
+    public static function rawNotice(string $message): self
     {
-        return Message::raw($message, Message::NOTICE);
+        return self::raw($message, self::NOTICE);
     }
 
     /**
@@ -328,9 +333,9 @@ class Message
      * @return Message
      * @static
      */
-    static public function rawSuccess($message)
+    public static function rawSuccess(string $message): self
     {
-        return Message::raw($message, Message::SUCCESS);
+        return self::raw($message, self::SUCCESS);
     }
 
     /**
@@ -341,13 +346,13 @@ class Message
      *
      * @return boolean whether this is a success message or not
      */
-    public function isSuccess($set = false)
+    public function isSuccess(bool $set = false): bool
     {
         if ($set) {
-            $this->setNumber(Message::SUCCESS);
+            $this->setNumber(self::SUCCESS);
         }
 
-        return $this->getNumber() === Message::SUCCESS;
+        return $this->getNumber() === self::SUCCESS;
     }
 
     /**
@@ -358,13 +363,13 @@ class Message
      *
      * @return boolean whether this is a notice message or not
      */
-    public function isNotice($set = false)
+    public function isNotice(bool $set = false): bool
     {
         if ($set) {
-            $this->setNumber(Message::NOTICE);
+            $this->setNumber(self::NOTICE);
         }
 
-        return $this->getNumber() === Message::NOTICE;
+        return $this->getNumber() === self::NOTICE;
     }
 
     /**
@@ -375,13 +380,13 @@ class Message
      *
      * @return boolean Whether this is an error message or not
      */
-    public function isError($set = false)
+    public function isError(bool $set = false): bool
     {
         if ($set) {
-            $this->setNumber(Message::ERROR);
+            $this->setNumber(self::ERROR);
         }
 
-        return $this->getNumber() === Message::ERROR;
+        return $this->getNumber() === self::ERROR;
     }
 
     /**
@@ -391,7 +396,7 @@ class Message
      *
      * @return void
      */
-    public function setBBCode($useBBCode)
+    public function setBBCode(bool $useBBCode): void
     {
         $this->useBBCode = $useBBCode;
     }
@@ -404,10 +409,10 @@ class Message
      *
      * @return void
      */
-    public function setMessage($message, $sanitize = false)
+    public function setMessage(string $message, bool $sanitize = false): void
     {
         if ($sanitize) {
-            $message = Message::sanitize($message);
+            $message = self::sanitize($message);
         }
         $this->message = $message;
     }
@@ -415,15 +420,15 @@ class Message
     /**
      * set string (does not take effect if raw message is set)
      *
-     * @param string  $string   string to set
-     * @param boolean $sanitize whether to sanitize $string or not
+     * @param string      $string   string to set
+     * @param boolean|int $sanitize whether to sanitize $string or not
      *
      * @return void
      */
-    public function setString($string, $sanitize = true)
+    public function setString(string $string, $sanitize = true): void
     {
         if ($sanitize) {
-            $string = Message::sanitize($string);
+            $string = self::sanitize($string);
         }
         $this->string = $string;
     }
@@ -435,7 +440,7 @@ class Message
      *
      * @return void
      */
-    public function setNumber($number)
+    public function setNumber(int $number): void
     {
         $this->number = $number;
     }
@@ -452,12 +457,12 @@ class Message
      *
      * @return void
      */
-    public function addParam($param)
+    public function addParam($param): void
     {
-        if ($param instanceof Message) {
+        if ($param instanceof self || is_float($param) || is_int($param)) {
             $this->params[] = $param;
         } else {
-            $this->params[] = htmlspecialchars($param);
+            $this->params[] = htmlspecialchars((string) $param);
         }
     }
 
@@ -466,16 +471,16 @@ class Message
      *
      * usage
      * <code>
-     * $message->addParamHtml('<img src="img" />');
+     * $message->addParamHtml('<img src="img">');
      * </code>
      *
      * @param string $param parameter to add
      *
      * @return void
      */
-    public function addParamHtml($param)
+    public function addParamHtml(string $param): void
     {
-        $this->params[] = Message::notice($param);
+        $this->params[] = self::notice($param);
     }
 
     /**
@@ -486,7 +491,7 @@ class Message
      *
      * @return void
      */
-    public function addMessages($messages, $separator = ' ')
+    public function addMessages(array $messages, string $separator = ' '): void
     {
         foreach ($messages as $message) {
             $this->addMessage($message, $separator);
@@ -501,7 +506,7 @@ class Message
      *
      * @return void
      */
-    public function addMessagesString($messages, $separator = ' ')
+    public function addMessagesString(array $messages, string $separator = ' '): void
     {
         foreach ($messages as $message) {
             $this->addText($message, $separator);
@@ -511,14 +516,14 @@ class Message
     /**
      * Real implementation of adding message
      *
-     * @param mixed  $message   to be added
-     * @param string $separator to use between this and previous string/message
+     * @param Message $message   to be added
+     * @param string  $separator to use between this and previous string/message
      *
      * @return void
      */
-    private function _addMessage($message, $separator)
+    private function addMessageToList(self $message, string $separator): void
     {
-        if (!empty($separator)) {
+        if (! empty($separator)) {
             $this->addedMessages[] = $separator;
         }
         $this->addedMessages[] = $message;
@@ -527,17 +532,14 @@ class Message
     /**
      * add another raw message to be concatenated on displaying
      *
-     * @param Message $message   to be added
-     * @param string  $separator to use between this and previous string/message
+     * @param self   $message   to be added
+     * @param string $separator to use between this and previous string/message
      *
      * @return void
      */
-    public function addMessage($message, $separator = ' ')
+    public function addMessage(self $message, string $separator = ' '): void
     {
-        if (!($message instanceof Message)) {
-            trigger_error('Invalid parameter passed to addMessage');
-        }
-        $this->_addMessage($message, $separator);
+        $this->addMessageToList($message, $separator);
     }
 
     /**
@@ -548,12 +550,9 @@ class Message
      *
      * @return void
      */
-    public function addText($message, $separator = ' ')
+    public function addText(string $message, string $separator = ' '): void
     {
-        if (!is_string($message)) {
-            trigger_error('Invalid parameter passed to addMessage');
-        }
-        $this->_addMessage(Message::notice(htmlspecialchars($message)), $separator);
+        $this->addMessageToList(self::notice(htmlspecialchars($message)), $separator);
     }
 
     /**
@@ -564,26 +563,23 @@ class Message
      *
      * @return void
      */
-    public function addHtml($message, $separator = ' ')
+    public function addHtml(string $message, string $separator = ' '): void
     {
-        if (!is_string($message)) {
-            trigger_error('Invalid parameter passed to addMessage');
-        }
-        $this->_addMessage(Message::rawNotice($message), $separator);
+        $this->addMessageToList(self::rawNotice($message), $separator);
     }
 
     /**
      * set all params at once, usually used in conjunction with string
      *
      * @param array|string $params   parameters to set
-     * @param boolean      $sanitize whether to sanitize params
+     * @param bool|int     $sanitize whether to sanitize params
      *
      * @return void
      */
-    public function setParams($params, $sanitize = false)
+    public function setParams($params, $sanitize = false): void
     {
         if ($sanitize) {
-            $params = Message::sanitize($params);
+            $params = self::sanitize($params);
         }
         $this->params = $params;
     }
@@ -591,7 +587,7 @@ class Message
     /**
      * return all parameters
      *
-     * @return array
+     * @return array|string
      */
     public function getParams()
     {
@@ -603,7 +599,7 @@ class Message
      *
      * @return array
      */
-    public function getAddedMessages()
+    public function getAddedMessages(): array
     {
         return $this->addedMessages;
     }
@@ -617,17 +613,17 @@ class Message
      * @access  public
      * @static
      */
-    static public function sanitize($message)
+    public static function sanitize($message)
     {
         if (is_array($message)) {
             foreach ($message as $key => $val) {
-                $message[$key] = Message::sanitize($val);
+                $message[$key] = self::sanitize($val);
             }
 
             return $message;
         }
 
-        return htmlspecialchars($message);
+        return htmlspecialchars((string) $message);
     }
 
     /**
@@ -640,25 +636,25 @@ class Message
      * @access  public
      * @static
      */
-    static public function decodeBB($message)
+    public static function decodeBB(string $message): string
     {
-        return Sanitize::sanitize($message, false, true);
+        return Sanitize::sanitizeMessage($message, false, true);
     }
 
     /**
      * wrapper for sprintf()
      *
+     * @param mixed[] ...$params Params
      * @return string formatted
      */
-    static public function format()
+    public static function format(...$params): string
     {
-        $params = func_get_args();
         if (isset($params[1]) && is_array($params[1])) {
             array_unshift($params[1], $params[0]);
             $params = $params[1];
         }
 
-        return call_user_func_array('sprintf', $params);
+        return sprintf(...$params);
     }
 
     /**
@@ -666,7 +662,7 @@ class Message
      *
      * @return string Message::$hash
      */
-    public function getHash()
+    public function getHash(): string
     {
         if (null === $this->hash) {
             $this->hash = md5(
@@ -684,7 +680,7 @@ class Message
      *
      * @return string complete message
      */
-    public function getMessage()
+    public function getMessage(): string
     {
         $message = $this->message;
 
@@ -701,11 +697,11 @@ class Message
             $message = $this->getMessageWithIcon($message);
         }
         if (count($this->getParams()) > 0) {
-            $message = Message::format($message, $this->getParams());
+            $message = self::format($message, $this->getParams());
         }
 
         if ($this->useBBCode) {
-            $message = Message::decodeBB($message);
+            $message = self::decodeBB($message);
         }
 
         foreach ($this->getAddedMessages() as $add_message) {
@@ -716,11 +712,11 @@ class Message
     }
 
     /**
-    * Returns only message string without image & other HTML.
-    *
-    * @return string
-    */
-    public function getOnlyMessage()
+     * Returns only message string without image & other HTML.
+     *
+     * @return string
+     */
+    public function getOnlyMessage(): string
     {
         return $this->message;
     }
@@ -731,7 +727,7 @@ class Message
      *
      * @return string Message::$string
      */
-    public function getString()
+    public function getString(): string
     {
         return $this->string;
     }
@@ -741,7 +737,7 @@ class Message
      *
      * @return integer Message::$number
      */
-    public function getNumber()
+    public function getNumber(): int
     {
         return $this->number;
     }
@@ -749,11 +745,11 @@ class Message
     /**
      * returns level of message
      *
-     * @return string  level of message
+     * @return string level of message
      */
-    public function getLevel()
+    public function getLevel(): string
     {
-        return Message::$level[$this->getNumber()];
+        return self::$level[$this->getNumber()];
     }
 
     /**
@@ -761,10 +757,9 @@ class Message
      *
      * @return void
      */
-    public function display()
+    public function display(): void
     {
         echo $this->getDisplay();
-        $this->isDisplayed(true);
     }
 
     /**
@@ -772,7 +767,7 @@ class Message
      *
      * @return string whole message box
      */
-    public function getDisplay()
+    public function getDisplay(): string
     {
         $this->isDisplayed(true);
         return '<div class="' . $this->getLevel() . '">'
@@ -786,7 +781,7 @@ class Message
      *
      * @return boolean Message::$isDisplayed
      */
-    public function isDisplayed($isDisplayed = false)
+    public function isDisplayed(bool $isDisplayed = false): bool
     {
         if ($isDisplayed) {
             $this->isDisplayed = true;
@@ -802,16 +797,16 @@ class Message
      *
      * @return string message with icon
      */
-    public function getMessageWithIcon($message)
+    public function getMessageWithIcon(string $message): string
     {
-        if ('error' == $this->getLevel()) {
+        if ('error' === $this->getLevel()) {
             $image = 's_error';
-        } elseif ('success' == $this->getLevel()) {
+        } elseif ('success' === $this->getLevel()) {
             $image = 's_success';
         } else {
             $image = 's_notice';
         }
-        $message = Message::notice(Util::getImage($image)) . " " . $message;
+        $message = self::notice(Util::getImage($image)) . " " . $message;
         return $message;
     }
 }
