@@ -1793,7 +1793,7 @@ class Sql
      * @param array               $analyzed_sql_results analysed sql results
      * @param string              $db                   current database
      * @param string              $table                current table
-     * @param string|null         $message              message to show
+     * @param Message|string|null $message              message to show
      * @param array|null          $sql_data             sql data
      * @param DisplayResults      $displayResultsObject Instance of DisplayResults
      * @param string              $pmaThemeImage        uri of the theme image
@@ -1818,7 +1818,7 @@ class Sql
         array $analyzed_sql_results,
         $db,
         $table,
-        ?string $message,
+        $message,
         ?array $sql_data,
         $displayResultsObject,
         $pmaThemeImage,
@@ -1933,7 +1933,7 @@ class Sql
             $scripts->addFile('makegrid.js');
             $scripts->addFile('sql.js');
             if (isset($message)) {
-                $message = Message::success($message);
+                $message = is_string($message) ? Message::success($message) : $message;
                 $tableMaintenanceHtml = Util::getMessage(
                     $message,
                     $GLOBALS['sql_query'],
