@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin;
 
 use PhpMyAdmin\Core;
@@ -21,6 +23,21 @@ use PhpMyAdmin\Util;
  */
 class UserPassword
 {
+    /**
+     * @var Privileges
+     */
+    private $serverPrivileges;
+
+    /**
+     * UserPassword constructor.
+     *
+     * @param Privileges $serverPrivileges Privileges object
+     */
+    public function __construct(Privileges $serverPrivileges)
+    {
+        $this->serverPrivileges = $serverPrivileges;
+    }
+
     /**
      * Send the message as an ajax request
      *
@@ -61,7 +78,7 @@ class UserPassword
         $error = false;
         $message = Message::success(__('The profile has been updated.'));
 
-        if (($_POST['nopass'] != '1')) {
+        if ($_POST['nopass'] != '1') {
             if (strlen($_POST['pma_pw']) === 0 || strlen($_POST['pma_pw2']) === 0) {
                 $message = Message::error(__('The password is empty!'));
                 $error = true;
@@ -75,7 +92,10 @@ class UserPassword
                 $error = true;
             }
         }
-        return array('error' => $error, 'msg' => $message);
+        return [
+            'error' => $error,
+            'msg' => $message,
+        ];
     }
 
     /**
@@ -103,8 +123,10 @@ class UserPassword
         ) {
             $orig_auth_plugin = $_POST['authentication_plugin'];
         } else {
-            $orig_auth_plugin = Privileges::getCurrentAuthenticationPlugin(
-                'change', $username, $hostname
+            $orig_auth_plugin = $this->serverPrivileges->getCurrentAuthenticationPlugin(
+                'change',
+                $username,
+                $hostname
             );
         }
 
@@ -114,7 +136,8 @@ class UserPassword
         if ($serverType == 'MySQL'
             && $serverVersion >= 50706
         ) {
-            $sql_query = 'ALTER USER \'' . $username . '\'@\'' . $hostname
+            $sql_query = 'ALTER USER \'' . $GLOBALS['dbi']->escapeString($username)
+                . '\'@\'' . $GLOBALS['dbi']->escapeString($hostname)
                 . '\' IDENTIFIED WITH ' . $orig_auth_plugin . ' BY '
                 . (($password == '') ? '\'\'' : '\'***\'');
         } elseif (($serverType == 'MySQL'
@@ -135,8 +158,12 @@ class UserPassword
         }
 
         $this->changePassUrlParamsAndSubmitQuery(
-            $username, $hostname, $password,
-            $sql_query, $hashing_function, $orig_auth_plugin
+            $username,
+            $hostname,
+            $password,
+            $sql_query,
+            $hashing_function,
+            $orig_auth_plugin
         );
 
         $auth_plugin->handlePasswordChange($password);
@@ -147,12 +174,14 @@ class UserPassword
     /**
      * Generate the hashing function
      *
-     * @return string  $hashing_function
+     * @return string
      */
     private function changePassHashingFunction()
     {
         if (Core::isValid(
-            $_POST['authentication_plugin'], 'identical', 'mysql_old_password'
+            $_POST['authentication_plugin'],
+            'identical',
+            'mysql_old_password'
         )) {
             $hashing_function = 'OLD_PASSWORD';
         } else {
@@ -174,7 +203,12 @@ class UserPassword
      * @return void
      */
     private function changePassUrlParamsAndSubmitQuery(
-        $username, $hostname, $password, $sql_query, $hashing_function, $orig_auth_plugin
+        $username,
+        $hostname,
+        $password,
+        $sql_query,
+        $hashing_function,
+        $orig_auth_plugin
     ) {
         $err_url = 'user_password.php' . Url::getCommon();
 
@@ -182,7 +216,8 @@ class UserPassword
         $serverVersion = $GLOBALS['dbi']->getVersion();
 
         if ($serverType == 'MySQL' && $serverVersion >= 50706) {
-            $local_query = 'ALTER USER \'' . $username . '\'@\'' . $hostname . '\''
+            $local_query = 'ALTER USER \'' . $GLOBALS['dbi']->escapeString($username)
+                . '\'@\'' . $GLOBALS['dbi']->escapeString($hostname) . '\''
                 . ' IDENTIFIED with ' . $orig_auth_plugin . ' BY '
                 . (($password == '')
                 ? '\'\''
@@ -202,14 +237,14 @@ class UserPassword
                 $GLOBALS['dbi']->tryQuery('SET `old_passwords` = 2;');
             }
 
-            $hashedPassword = Privileges::getHashedPassword($_POST['pma_pw']);
+            $hashedPassword = $this->serverPrivileges->getHashedPassword($_POST['pma_pw']);
 
             $local_query = "UPDATE `mysql`.`user` SET"
                 . " `authentication_string` = '" . $hashedPassword
                 . "', `Password` = '', "
                 . " `plugin` = '" . $orig_auth_plugin . "'"
-                . " WHERE `User` = '" . $username . "' AND Host = '"
-                . $hostname . "';";
+                . " WHERE `User` = '" . $GLOBALS['dbi']->escapeString($username)
+                . "' AND Host = '" . $GLOBALS['dbi']->escapeString($hostname) . "';";
         } else {
             $local_query = 'SET password = ' . (($password == '')
                 ? '\'\''
@@ -241,7 +276,9 @@ class UserPassword
     {
         echo '<h1>' , __('Change password') , '</h1>' , "\n\n";
         echo Util::getMessage(
-            $message, $sql_query, 'success'
+            $message,
+            $sql_query,
+            'success'
         );
         echo '<a href="index.php' , Url::getCommon()
             , ' target="_parent">' , "\n"
