@@ -5,10 +5,15 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
 
 use PhpMyAdmin\Core;
 
-require_once 'libraries/common.inc.php';
+if (! defined('ROOT_PATH')) {
+    define('ROOT_PATH', __DIR__ . DIRECTORY_SEPARATOR);
+}
+
+require_once ROOT_PATH . 'libraries/common.inc.php';
 
 if ($_SERVER['REQUEST_METHOD'] != 'POST' || $token_mismatch) {
     Core::sendHeaderLocation('./index.php');
