@@ -5,12 +5,17 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
+if (! defined('ROOT_PATH')) {
+    define('ROOT_PATH', __DIR__ . DIRECTORY_SEPARATOR);
+}
 
 /**
  * Gets core libraries and defines some variables
  */
-require_once 'libraries/common.inc.php';
-$response = PMA\libraries\Response::getInstance();
+require_once ROOT_PATH . 'libraries/common.inc.php';
+$response = PhpMyAdmin\Response::getInstance();
 $response->disable();
 $response->getHeader()->sendHttpHeaders();
 
